@@ -1,7 +1,5 @@
 package Devel::FindPerl;
-{
-  $Devel::FindPerl::VERSION = '0.012';
-}
+$Devel::FindPerl::VERSION = '0.013';
 use strict;
 use warnings;
 
@@ -33,8 +31,8 @@ sub _discover_perl_interpreter {
 
 	my @potential_perls;
 
-	# Try 1, Check $^X for absolute path
-	push @potential_perls, [ file_name_is_absolute($^X) ? $^X : rel2abs($^X) ] unless tainted($^X);
+	# Try 1, Check $^X for absolute and relative path
+	push @potential_perls, file_name_is_absolute($^X) ? [ $^X ] : length +(splitpath($^X))[1] ? [ rel2abs($^X) ] : ();
 
 	# Try 2, Last ditch effort: These two option use hackery to try to locate
 	# a suitable perl. The hack varies depending on whether we are running
@@ -44,16 +42,16 @@ sub _discover_perl_interpreter {
 		# perl, we can keep moving up the directory tree until we find our
 		# binary. We wouldn't do this under any other circumstances.
 
-		my $perl_src = realpath(_perl_src());
+		my $perl_src = _perl_src();
 		if (defined($perl_src) && length($perl_src)) {
-			my $uninstperl = rel2abs(catfile($perl_src, $perl_basename));
+			my $uninstperl = catfile($perl_src, $perl_basename);
 			# When run from the perl core, @INC will include the directories
 			# where perl is yet to be installed. We need to reference the
 			# absolute path within the source distribution where it can find
 			# it's Config.pm This also prevents us from picking up a Config.pm
 			# from a different configuration that happens to be already
 			# installed in @INC.
-			push @potential_perls, [ $uninstperl, '-I' . catdir(dirname($^X), 'lib') ];
+			push @potential_perls, [ $uninstperl, '-I' . catdir($perl_src, 'lib') ];
 		}
 	}
 	else {
@@ -62,15 +60,16 @@ sub _discover_perl_interpreter {
 		# uninstalled perl in a perl source tree.
 
 		push @potential_perls, [ $config->get('perlpath') ];
-		push @potential_perls, map { [ catfile($_, $perl_basename) ] } grep { !tainted($_) } path();
+		push @potential_perls, map { [ catfile($_, $perl_basename) ] } path();
 	}
+	@potential_perls = grep { !tainted($_->[0]) } @potential_perls;
 
 	# Now that we've enumerated the potential perls, it's time to test
 	# them to see if any of them match our configuration, returning the
 	# absolute path of the first successful match.
 	my $exe = $config->get('exe_ext');
 	foreach my $thisperl (@potential_perls) {
-		$thisperl->[0] .= $exe if length $exe and $thisperl->[0] !~ m/$exe$/i;
+		$thisperl->[0] .= $exe if length $exe and $thisperl->[0] !~ m/\Q$exe$/i;
 		return $thisperl if -f $thisperl->[0] && perl_is_same(@{$thisperl});
 	}
 
@@ -106,20 +105,23 @@ sub _perl_src {
 	}
 
 	carp "PERL_CORE is set but I can't find your perl source!\n";
-	return; # return empty string if $ENV{PERL_CORE} but can't find dir ???
+	return;
 }
 
 sub perl_is_same {
-	my @cmd = @_;
+	my @perl = @_;
+	return lc _capture_command(@perl, qw(-MConfig=myconfig -e print -e myconfig)) eq lc Config->myconfig;
+}
 
-	push @cmd, qw(-MConfig=myconfig -e print -e myconfig);
+sub _capture_command {
+	my (@command) = @_;
 
-	local @ENV{qw/PATH IFS CDPATH ENV BASH_ENV/} = ('') x 5;
-	my $pid = open2(my($in, $out), @cmd);
+	local @ENV{qw/PATH IFS CDPATH ENV BASH_ENV/};
+	my $pid = open2(my($in, $out), @command);
 	binmode $in, ':crlf' if $^O eq 'MSWin32';
 	my $ret = do { local $/; <$in> };
 	waitpid $pid, 0;
-	return lc $ret eq lc Config->myconfig;
+	return $ret;
 }
 
 sub Devel::FindPerl::Config::get {
@@ -143,7 +145,7 @@ Devel::FindPerl - Find the path to your perl
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
